@@ -5,7 +5,7 @@ test_that("get_wdid returns correct results", {
   skip_on_cran()
 
   # test general
-  comps <- c('DDT', 'Aspirin', 'xdewrwdcadsr4w')
+  comps <- c('DDT', 'Aspirin', 'xdewrwdcadsr4w', 'acetic acid')
   o1 <- get_wdid(comps, match = 'best')
   o2 <- get_wdid(comps, match = 'all')
   o3 <- get_wdid(comps[1], match = 'first')
@@ -17,7 +17,7 @@ test_that("get_wdid returns correct results", {
   expect_is(o3, 'data.frame')
   expect_is(o4, 'data.frame')
 
-  expect_equal(o1$id, c("Q163648", "Q10420388", NA))
+  expect_equal(o1$id, c("Q163648", "Q10420388", NA, 'Q47512'))
   expect_equivalent(o2[[1]][1:2], c("Q163648", "Q949424"))
   expect_equal(o3$distance, 'first')
   expect_equal(o4$distance, NA)
